@@ -12,14 +12,14 @@ class CrudAPIController(ControllerBase, CrudAPI, metaclass=CrudApiMetaclass):
     Base APIController for auto creating CRUD APIs
 
     GET /{id}       - Retrieve a single Object
-    PUT /           -  Create a single Object
-    PATCH /?id={id} - Update a single field for a Object
+    PUT /{id}               - Create a single Object
+    PATCH /{id}     - Update fields for an Object
     DELETE /{id}    - Delete a single Object
-    GET /get_all    - Retrieve multiple Object
+    GET /           - Retrieve multiple Object, paginated
     GET /filter/?filters={filters_dict}
-                    - Filter Objects with django-orm filter dict
+                        - Filter Objects with django-orm filter dict, paginated
     GET /filter_exclude/?filters={filters_dict}
-                    - Filter exclude Objects with Django-ORM filter dict
+                        - Filter exclude Objects with Django-ORM filter dict, paginated
 
     """
 
